@@ -375,25 +375,25 @@ class GCP:
         )
 
     @staticmethod
-    def latest_file(bucket_name: str) -> str:
+    def make_files_times_dict(bucket_name: str, prefix: str = None) -> dict:
         """
-        Identifies and retrieves the latest file based on the specified
-        bucket name.
+        Identifies and retrieves the file names with their times of creation.
 
         Parameters
         ----------
         bucket_name: str, the name of the bucket
+        prefix: str, the name of the sub folder, eg 'public/'.
 
         Returns
         -------
-        A string with the filename of the latest file in the bucket.
+        A dict with the filenames in the bucket and their times of creation.
 
         """
         # Initialise the client
         storage_client = storage.Client()
 
         # Make the blobs
-        blobs = storage_client.list_blobs(bucket_name)
+        blobs = storage_client.list_blobs(bucket_name, prefix=prefix)
 
         names = []
         times_created = []
@@ -404,13 +404,70 @@ class GCP:
             names.append(name)
             times_created.append(time_created)
 
-        names_times_dict = dict(zip(times_created, names))
+        return dict(zip(names, times_created))
+
+    @staticmethod
+    def get_latest_file(bucket_name: str, prefix: str = None) -> str:
+        """
+        Identifies and retrieves the latest file based on the specified
+        bucket name.
+
+        Parameters
+        ----------
+        bucket_name: str, the name of the bucket
+        prefix: str, the name of the sub folder, eg 'public/'.
+
+        Returns
+        -------
+        A string with the filename of the latest file in the bucket.
+
+        """
+        # Create the names_times_dict using the func make_files_times_dict
+        names_times_dict = GCP.make_files_times_dict(
+            bucket_name=bucket_name, prefix=prefix
+        )
+        times_created = list(names_times_dict.values())
 
         # Find the latest datetime object
         latest = max(times_created)
 
         # Return the filename of the latest object
-        return names_times_dict.get(latest)
+        return list(names_times_dict.keys())[
+            list(names_times_dict.values()).index(latest)
+        ]
+
+    @staticmethod
+    def get_latest_sub_folder(bucket_name: str, prefix: str = None) -> str:
+        """
+        Identifies and retrieves the latest sub folder based on a bucket name and prefix.
+
+        Parameters
+        ----------
+        bucket_name: str, the name of the bucket.
+        prefix: str, the name of the sub folder, eg 'public/'.
+
+        Returns
+        -------
+        A string with the latest sub folder within a bucket and prefix.
+
+        """
+        # Create the names_times_dict using the func make_files_times_dict
+        names_times_dict = GCP.make_files_times_dict(
+            bucket_name=bucket_name, prefix=prefix
+        )
+        names = list(names_times_dict.keys())
+
+        # Retrieve the sub folders
+        sub_folders = [name for name in names if name.endswith("/")][1:]
+        sub_folders_times_dict = {key: names_times_dict[key] for key in sub_folders}
+
+        # Find the latest datetime object
+        latest = max(list(sub_folders_times_dict.values()))
+
+        # Return the sub folder of the latest object
+        return list(sub_folders_times_dict.keys())[
+            list(sub_folders_times_dict.values()).index(latest)
+        ]
 
 
 class CloudSQL:
